@@ -289,7 +289,7 @@ brma.default <-
     prior_template <- list(
       lasso = c(df = 1, scale = 1),
       hs = c(df = 1, df_global = 1,
-             df_slab = 4, scale_global = 1, scale_slab = 2, relevant_pars = NULL))[[method]]
+             df_slab = 4, scale_global = 1, scale_slab = 2, relevant_pars = NA))[[method]]
     legalnames <- names(prior_template)
     is_legal <- names(prior) %in% legalnames
     if(any(!is_legal)){
