@@ -3,7 +3,6 @@
 #' @description Penalized meta-regression shrinks the regression slopes of
 #' irrelevant moderators towards zero (Van Lissa & Van Erp, 2021).
 #'
-#' @docType package
 #' @name pema-package
 #' @aliases pema
 #' @useDynLib pema, .registration = TRUE
@@ -20,4 +19,4 @@
 #' Stan Development Team (NA). RStan: the R interface to Stan. R package version
 #' 2.26.2. \url{https://mc-stan.org}
 #'
-NULL
+"_PACKAGE"
